@@ -8,7 +8,7 @@
 #
 # Duplicity is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 3 of the License, or (at your
+# Free Software Foundation; either version 2 of the License, or (at your
 # option) any later version.
 #
 # Duplicity is distributed in the hope that it will be useful, but
@@ -118,6 +118,7 @@ class WarningCode:
     unmatched_sig = 4
     incomplete_backup = 5
     orphaned_backup = 6
+    ftp_ncftp_v320 = 7 # moved from error
 
 def Warn(s, code=WarningCode.generic):
     """Shortcut used for warning messages (verbosity 2)"""
@@ -156,9 +157,11 @@ class ErrorCode:
     boto_calling_format = 26
     ftp_ncftp_missing = 27
     ftp_ncftp_too_old = 28
-    ftp_ncftp_v320 = 29
+    #ftp_ncftp_v320 = 29 # moved to warning
     exception = 30
     gpg_failed = 31
+    s3_bucket_not_style = 32
+    not_implemented = 33
 
 def FatalError(s, code, extra=None):
     """Write fatal error message and exit"""
